"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const coc_nvim_1 = require("coc.nvim");
function activate(context) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        let { subscriptions } = context;
        const config = coc_nvim_1.workspace.getConfiguration().get('docker', {});
        const enable = config.enable;
        if (enable === false)
            return;
        let serverModule = context.asAbsolutePath(path_1.default.join('node_modules', 'dockerfile-language-server-nodejs', 'lib', 'server.js'));
        let serverOptions = {
            run: {
                module: serverModule,
                transport: coc_nvim_1.TransportKind.ipc,
                args: ["--node-ipc"]
            },
            debug: {
                module: serverModule,
                transport: coc_nvim_1.TransportKind.ipc,
                options: { execArgv: ["--nolazy", "--inspect=6009"] }
            }
        };
        let clientOptions = {
            documentSelector: ['Dockerfile'],
            synchronize: {
                fileEvents: coc_nvim_1.workspace.createFileSystemWatcher("**/.clientrc")
            }
        };
        const client = new coc_nvim_1.LanguageClient("dockerfile-langserver", "Dockerfile Language Server", serverOptions, clientOptions);
        subscriptions.push(coc_nvim_1.services.registLanguageClient(client));
        subscriptions.push(coc_nvim_1.commands.registerCommand("docker.version", () => tslib_1.__awaiter(this, void 0, void 0, function* () {
            const v = require(path_1.default.resolve(__dirname, '..', 'package.json')).version;
            coc_nvim_1.workspace.showMessage(`Version: ${v}`, 'more');
        })));
    });
}
exports.activate = activate;
//# sourceMappingURL=extension.js.map